@@ -1,8 +1,9 @@
 # frozen_string_literal: true
 
 require 'log4r'
-require 'vagrant/util/network_ip'
-require 'vagrant/util/scoped_hash_override'
+
+require 'vagrant-libvirt/util/erb_template'
+require 'vagrant-libvirt/util/network_util'
 
 module VagrantPlugins
   module ProviderLibvirt
@@ -12,15 +13,12 @@ module VagrantPlugins
       class CreateNetworkInterfaces
         include VagrantPlugins::ProviderLibvirt::Util::ErbTemplate
         include VagrantPlugins::ProviderLibvirt::Util::NetworkUtil
-        include Vagrant::Util::NetworkIP
-        include Vagrant::Util::ScopedHashOverride
 
         def initialize(app, env)
           @logger = Log4r::Logger.new('vagrant_libvirt::action::create_network_interfaces')
           @management_network_name = env[:machine].provider_config.management_network_name
           config = env[:machine].provider_config
-          @nic_model_type = config.nic_model_type || 'virtio'
-          @nic_adapter_count = config.nic_adapter_count
+          @nic_model_type = config.nic_model_type
           @app = app
         end
 
@@ -36,34 +34,7 @@ module VagrantPlugins
           end
 
           # Setup list of interfaces before creating them.
-          adapters = []
-
-          # Vagrant gives you adapter 0 by default
-          # Assign interfaces to slots.
-          configured_networks(env, @logger).each do |options|
-            # don't need to create interface for this type
-            next if options[:iface_type] == :forwarded_port
-
-            # TODO: fill first ifaces with adapter option specified.
-            if options[:adapter]
-              if adapters[options[:adapter]]
-                raise Errors::InterfaceSlotNotAvailable
-              end
-
-              free_slot = options[:adapter].to_i
-              @logger.debug "Using specified adapter slot #{free_slot}"
-            else
-              free_slot = find_empty(adapters)
-              @logger.debug "Adapter not specified so found slot #{free_slot}"
-              raise Errors::InterfaceSlotExhausted if free_slot.nil?
-            end
-
-            # We have slot for interface, fill it with interface configuration.
-            adapters[free_slot] = options
-            adapters[free_slot][:network_name] = interface_network(
-              env[:machine].provider.driver, adapters[free_slot]
-            )
-          end
+          adapters = network_interfaces(env[:machine], @logger)
 
           # Create each interface as new domain device.
           @macs_per_network = Hash.new(0)
@@ -78,7 +49,7 @@ module VagrantPlugins
             @driver_name = iface_configuration.fetch(:driver_name, false)
             @driver_iommu = iface_configuration.fetch(:driver_iommu, false )
             @driver_queues = iface_configuration.fetch(:driver_queues, false)
-            @device_name = iface_configuration.fetch(:iface_name, false)
+            @device_name = iface_configuration.fetch(:iface_name, nil)
             @mtu = iface_configuration.fetch(:mtu, nil)
             @pci_bus = iface_configuration.fetch(:bus, nil)
             @pci_slot = iface_configuration.fetch(:slot, nil)
@@ -96,6 +67,7 @@ module VagrantPlugins
               @driver_iommu = iface_configuration.fetch(:driver_iommu, false )
               @driver_name = iface_configuration.fetch(:driver_name, false)
               @driver_queues = iface_configuration.fetch(:driver_queues, false)
+              @device_name = iface_configuration.fetch(:iface_name, nil)
               @portgroup = iface_configuration.fetch(:portgroup, nil)
               @network_name = iface_configuration.fetch(:network_name, @network_name)
               template_name = 'public_interface'
@@ -146,7 +118,7 @@ module VagrantPlugins
               # FIXME: all options for network driver should be hash from Vagrantfile
               driver_options = {}
               driver_options[:name] = @driver_name if @driver_name
-              driver_options[:iommu] = @driver_iommu ? "on" : "off" if @nic_model_type == 'virtio'
+              driver_options[:iommu] = @driver_iommu ? "on" : "off" if @model_type == 'virtio'
               driver_options[:queues] = @driver_queues if @driver_queues
 
               @udp_tunnel ||= {}
@@ -169,7 +141,7 @@ module VagrantPlugins
               @logger.debug {
                 "Attaching Network Device with XML:\n#{xml}"
               }
-              domain.attach_device(xml)
+              env[:machine].provider.driver.attach_device(xml)
             rescue => e
               raise Errors::AttachDeviceError,
                     error_message: e.message
@@ -282,41 +254,6 @@ module VagrantPlugins
                        Nokogiri::XML::Node::SaveOptions::FORMAT
           )
         end
-
-        def find_empty(array, start = 0, stop = @nic_adapter_count)
-          (start..stop).each do |i|
-            return i unless array[i]
-          end
-          nil
-        end
-
-        # Return network name according to interface options.
-        def interface_network(driver, options)
-          # no need to get interface network for tcp tunnel config
-          return 'tunnel_interface' if options.fetch(:tunnel_type, nil)
-
-          if options[:network_name]
-            @logger.debug 'Found network by name'
-            return options[:network_name]
-          end
-
-          # Get list of all (active and inactive) Libvirt networks.
-          available_networks = libvirt_networks(driver)
-
-          return 'public' if options[:iface_type] == :public_network
-
-          if options[:ip]
-            address = network_address(options[:ip], options[:netmask])
-            available_networks.each do |network|
-              if address == network[:network_address]
-                @logger.debug 'Found network by ip'
-                return network[:name]
-              end
-            end
-          end
-
-          raise Errors::NetworkNotAvailableError, network_name: options[:ip]
-        end
       end
     end
   end
