@@ -12,7 +12,9 @@ module VagrantPlugins
         end
 
         def call(env)
-          env[:ui].info('Vagrant-libvirt plugin removed box only from your LOCAL ~/.vagrant/boxes directory')
+          return @app.call(env) unless env[:box_removed].provider == :libvirt
+
+          env[:ui].info("Vagrant-libvirt plugin removed box only from #{env[:env].boxes.directory} directory")
           env[:ui].info('From Libvirt storage pool you have to delete image manually(virsh, virt-manager or by any other tool)')
           @app.call(env)
         end
