@@ -12,7 +12,7 @@ module VagrantPlugins
           env[:ui].info(I18n.t(
             "vagrant.actions.vm.snapshot.restoring",
             name: env[:snapshot_name]))
-          env[:machine].provider.driver.restore_snapshot(env[:machine], env[:snapshot_name])
+          env[:machine].provider.driver.restore_snapshot(env[:snapshot_name])
 
           @app.call(env)
         end
