@@ -6,6 +6,7 @@ require 'rexml/document'
 require 'rexml/formatters/pretty'
 require 'rexml/xpath'
 
+require 'vagrant-libvirt/util/network_util'
 require 'vagrant-libvirt/util/xml'
 
 module VagrantPlugins
@@ -13,9 +14,11 @@ module VagrantPlugins
     module Action
       # Just start the domain.
       class StartDomain
+        include VagrantPlugins::ProviderLibvirt::Util::NetworkUtil
 
-        def initialize(app, _env)
+        def initialize(app, env)
           @logger = Log4r::Logger.new('vagrant_libvirt::action::start_domain')
+          config = env[:machine].provider_config
           @app = app
         end
 
@@ -68,14 +71,44 @@ module VagrantPlugins
           end
 
           # Interface type
-          unless config.nic_model_type.nil?
-            REXML::XPath.each(xml_descr, '/domain/devices/interface/model') do |iface_model|
-              if iface_model.attributes['type'] != config.nic_model_type
-                @logger.debug "network type updated from '#{iface_model.attributes['type']}' to '#{config.nic_model_type}'"
+          adapters = network_interfaces(env[:machine], @logger)
+          index = 0
+          REXML::XPath.each(xml_descr, '/domain/devices/interface') do |iface|
+            # initial config defaults
+            nic_model_type = index == 0 && config.mgmt_attach ? config.management_network_model_type :  config.nic_model_type
+            driver_iommu = index == 0 && config.mgmt_attach ? config.management_network_driver_iommu : false
+            # resolve per adapter option
+            if index < adapters.length
+              nic_model_type = adapters[index].fetch(:model_type, nic_model_type)
+              driver_iommu = adapters[index].fetch(:driver_iommu, driver_iommu )
+            end
+
+            iface_model = iface.elements['model']
+            if iface_model.attributes['type'] != nic_model_type
+              @logger.debug "network type updated from '#{iface_model.attributes['type']}' to '#{nic_model_type}'"
+              descr_changed = true
+              iface_model.attributes['type'] = nic_model_type
+            end
+
+            iface_driver = iface.elements['driver'] || REXML::Element.new('driver', iface)
+
+            if nic_model_type == 'virtio'
+              iommu = driver_iommu ? 'on': 'off'
+              if !iface_driver.attributes['iommu'].nil? && !driver_iommu.nil? && iface_driver.attributes['iommu'] != iommu
                 descr_changed = true
-                iface_model.attributes['type'] = config.nic_model_type
+                iface_driver.attributes['iommu'] = iommu
+              end
+            else
+              if !iface_driver.nil?
+                descr_changed = true if iface_driver.attributes['iommu']
+                iface_driver.attributes.delete('iommu')
               end
             end
+            iface.delete_element(iface_driver) if iface_driver.attributes.empty?
+            index += 1
+          end
+          if adapters.length != index
+            env[:ui].warn("number of network adapters in current config (#{adapters.length}) is different to attached interfaces (#{index}), may have incorrectly updated")
           end
 
           # vCpu count
@@ -166,12 +199,29 @@ module VagrantPlugins
             xml_descr.delete_element('/domain/cpu')
           end
 
-          # Clock
+          # Clock - can change in complicated ways, so just build a new clock and compare
+          newclock = REXML::Element.new('newclock')
+          if not config.clock_absolute.nil?
+            newclock.add_attribute('offset', 'absolute')
+            newclock.add_attribute('start', config.clock_absolute)
+          elsif not config.clock_adjustment.nil?
+            newclock.add_attribute('offset', 'variable')
+            newclock.add_attribute('basis', config.clock_basis)
+            newclock.add_attribute('adjustment', config.clock_adjustment)
+          elsif not config.clock_timezone.nil?
+            newclock.add_attribute('offset', 'timezone')
+            newclock.add_attribute('timezone', config.clock_timezone)
+          else
+            newclock.add_attribute('offset', config.clock_offset)
+          end
           clock = REXML::XPath.first(xml_descr, '/domain/clock')
-          if clock.attributes['offset'] != config.clock_offset
-            @logger.debug "clock offset changed"
+          if clock.attributes != newclock.attributes
+            @logger.debug "clock definition changed"
             descr_changed = true
-            clock.attributes['offset'] = config.clock_offset
+            clock.attributes.clear
+            newclock.attributes.each do |attr, value|
+              clock.add_attribute(attr, value)
+            end
           end
 
           # clock timers - because timers can be added/removed, just rebuild and then compare
@@ -272,13 +322,25 @@ module VagrantPlugins
               graphics.attributes['listen'] = config.graphics_ip
               graphics.delete_element('//listen')
             end
-            if graphics.attributes['autoport'] != config.graphics_autoport
-              descr_changed = true
-              graphics.attributes['autoport'] = config.graphics_autoport
-              if config.graphics_autoport == 'no'
-                graphics.attributes.delete('autoport')
+            unless config.graphics_port.nil? or config.graphics_port == -1
+              if graphics.attributes['autoport'] != 'no'
+                descr_changed = true
+                graphics.attributes['autoport'] = 'no'
+              end
+              if graphics.attributes['port'] != config.graphics_port
+                descr_changed = true
                 graphics.attributes['port'] = config.graphics_port
               end
+            else
+              if graphics.attributes['autoport'] != config.graphics_autoport
+                descr_changed = true
+                graphics.attributes['autoport'] = config.graphics_autoport
+                if config.graphics_autoport == 'no'
+                  graphics.attributes['port'] = config.graphics_port
+                else
+                  graphics.attributes['port'] = '-1'
+                end
+              end
             end
             if graphics.attributes['websocket'] != config.graphics_websocket.to_s
               descr_changed = true
