@@ -5,9 +5,11 @@ require 'ostruct'
 require 'nokogiri'
 require 'digest/md5'
 
-require 'vagrant/util/subprocess'
 require 'vagrant/errors'
+require 'vagrant/util/subprocess'
+
 require 'vagrant-libvirt/errors'
+require 'vagrant-libvirt/util/erb_template'
 
 module VagrantPlugins
   module SyncedFolderVirtioFS
@@ -34,6 +36,8 @@ module VagrantPlugins
         raise Vagrant::Errors::Error('No Libvirt connection') if machine.provider.driver.connection.nil?
         @conn = machine.provider.driver.connection.client
 
+        machine.ui.info I18n.t("vagrant_libvirt.cap.virtiofs.preparing")
+
         begin
           # loop through folders
           folders.each do |id, folder_opts|
@@ -44,8 +48,6 @@ module VagrantPlugins
             mount_tag = Digest::MD5.new.update(folder_opts[:hostpath]).to_s[0, 31]
             folder_opts[:mount_tag] = mount_tag
 
-            machine.ui.info "================\nMachine id: #{machine.id}\nShould be mounting folders\n #{id}, opts: #{folder_opts}"
-
             xml = Nokogiri::XML::Builder.new do |xml|
               xml.filesystem(type: 'mount', accessmode: 'passthrough') do
                 xml.driver(type: 'virtiofs')
@@ -73,7 +75,7 @@ module VagrantPlugins
       # once up, mount folders
       def enable(machine, folders, _opts)
         # Go through each folder and mount
-        machine.ui.info('mounting virtiofs share in guest')
+        machine.ui.info I18n.t("vagrant_libvirt.cap.virtiofs.mounting")
         # Only mount folders that have a guest path specified.
         mount_folders = {}
         folders.each do |id, opts|
@@ -91,6 +93,7 @@ module VagrantPlugins
           raise Vagrant::Errors::Error('No Libvirt connection')
         end
         @conn = machine.provider.driver.connection.client
+        machine.ui.info I18n.t("vagrant_libvirt.cap.virtiofs.cleanup")
         begin
           if machine.id && machine.id != ''
             dom = @conn.lookup_domain_by_uuid(machine.id)
@@ -98,7 +101,6 @@ module VagrantPlugins
               '/domain/devices/filesystem'
             ).each do |xml|
               dom.detach_device(xml.to_s)
-              machine.ui.info 'Cleaned up shared folders'
             end
           end
         rescue => e
