@@ -7,11 +7,13 @@ require 'vagrant/action/builtin/mixin_synced_folders'
 
 require 'vagrant-libvirt/errors'
 require 'vagrant-libvirt/util/resolvers'
+require 'vagrant-libvirt/util/network_util'
 
 module VagrantPlugins
   module ProviderLibvirt
     class Config < Vagrant.plugin('2', :config)
       include Vagrant::Action::Builtin::MixinSyncedFolders
+      include VagrantPlugins::ProviderLibvirt::Util::NetworkUtil
 
       # manually specify URI
       # will supersede most other options if provided
@@ -68,6 +70,8 @@ module VagrantPlugins
       attr_accessor :management_network_mtu
       attr_accessor :management_network_keep
       attr_accessor :management_network_driver_iommu
+      attr_accessor :management_network_iface_name
+      attr_accessor :management_network_model_type
 
       # System connection information
       attr_accessor :system_uri
@@ -95,7 +99,11 @@ module VagrantPlugins
       attr_accessor :shares
       attr_accessor :features
       attr_accessor :features_hyperv
+      attr_accessor :clock_absolute
+      attr_accessor :clock_adjustment
+      attr_accessor :clock_basis
       attr_accessor :clock_offset
+      attr_accessor :clock_timezone
       attr_accessor :clock_timers
       attr_accessor :launchsecurity_data
       attr_accessor :numa_nodes
@@ -222,6 +230,8 @@ module VagrantPlugins
       ]
 
       def initialize
+        @logger = Log4r::Logger.new("vagrant_libvirt::config")
+
         @uri               = UNSET_VALUE
         @driver            = UNSET_VALUE
         @host              = UNSET_VALUE
@@ -249,6 +259,8 @@ module VagrantPlugins
         @management_network_mtu = UNSET_VALUE
         @management_network_keep = UNSET_VALUE
         @management_network_driver_iommu = UNSET_VALUE
+        @management_network_iface_name = UNSET_VALUE
+        @management_network_model_type = UNSET_VALUE
 
         # System connection information
         @system_uri      = UNSET_VALUE
@@ -272,7 +284,11 @@ module VagrantPlugins
         @shares            = UNSET_VALUE
         @features          = UNSET_VALUE
         @features_hyperv   = UNSET_VALUE
+        @clock_absolute    = UNSET_VALUE
+        @clock_adjustment  = UNSET_VALUE
+        @clock_basis       = UNSET_VALUE
         @clock_offset      = UNSET_VALUE
+        @clock_timezone    = UNSET_VALUE
         @clock_timers      = []
         @launchsecurity_data = UNSET_VALUE
         @numa_nodes        = UNSET_VALUE
@@ -720,7 +736,7 @@ module VagrantPlugins
 
       # Disk driver options for primary disk
       def disk_driver(options = {})
-        supported_opts = [:cache, :io, :copy_on_read, :discard, :detect_zeroes]
+        supported_opts = [:cache, :io, :copy_on_read, :discard, :detect_zeroes, :type]
         @disk_driver_opts = options.select { |k,_| supported_opts.include? k }
       end
 
@@ -946,19 +962,6 @@ module VagrantPlugins
         @snapshot_pool_name = @storage_pool_name if @snapshot_pool_name == UNSET_VALUE
         @storage_pool_path = nil if @storage_pool_path == UNSET_VALUE
         @random_hostname = false if @random_hostname == UNSET_VALUE
-        @management_network_device = 'virbr0' if @management_network_device == UNSET_VALUE
-        @management_network_name = 'vagrant-libvirt' if @management_network_name == UNSET_VALUE
-        @management_network_address = '192.168.121.0/24' if @management_network_address == UNSET_VALUE
-        @management_network_mode = 'nat' if @management_network_mode == UNSET_VALUE
-        @management_network_mac = nil if @management_network_mac == UNSET_VALUE
-        @management_network_guest_ipv6 = 'yes' if @management_network_guest_ipv6 == UNSET_VALUE
-        @management_network_autostart = false if @management_network_autostart == UNSET_VALUE
-        @management_network_pci_bus = nil if @management_network_pci_bus == UNSET_VALUE
-        @management_network_pci_slot = nil if @management_network_pci_slot == UNSET_VALUE
-        @management_network_domain = nil if @management_network_domain == UNSET_VALUE
-        @management_network_mtu = nil if @management_network_mtu == UNSET_VALUE
-        @management_network_keep = false if @management_network_keep == UNSET_VALUE
-        @management_network_driver_iommu = false if @management_network_driver_iommu == UNSET_VALUE
 
         # Domain specific settings.
         @title = '' if @title == UNSET_VALUE
@@ -995,7 +998,11 @@ module VagrantPlugins
         @shares = nil if @shares == UNSET_VALUE
         @features = ['acpi','apic','pae'] if @features == UNSET_VALUE
         @features_hyperv = [] if @features_hyperv == UNSET_VALUE
+        @clock_absolute = nil if @clock_absolute == UNSET_VALUE
+        @clock_adjustment = nil if @clock_adjustment == UNSET_VALUE
+        @clock_basis = 'utc' if @clock_basis == UNSET_VALUE
         @clock_offset = 'utc' if @clock_offset == UNSET_VALUE
+        @clock_timezone = nil if @clock_timezone == UNSET_VALUE
         @clock_timers = [] if @clock_timers == UNSET_VALUE
         @launchsecurity_data = nil if @launchsecurity_data == UNSET_VALUE
         @numa_nodes = @numa_nodes == UNSET_VALUE ? nil : _generate_numa
@@ -1013,7 +1020,7 @@ module VagrantPlugins
         end
         @disk_address_type = nil if @disk_address_type == UNSET_VALUE
         @disk_driver_opts = {} if @disk_driver_opts == UNSET_VALUE
-        @nic_model_type = nil if @nic_model_type == UNSET_VALUE
+        @nic_model_type = 'virtio' if @nic_model_type == UNSET_VALUE
         @nested = false if @nested == UNSET_VALUE
         @volume_cache = nil if @volume_cache == UNSET_VALUE
         @kernel = nil if @kernel == UNSET_VALUE
@@ -1128,6 +1135,23 @@ module VagrantPlugins
 
         @serials = [{:type => 'pty', :source => nil}] if @serials == UNSET_VALUE
 
+        # management network options
+        @management_network_device = 'virbr0' if @management_network_device == UNSET_VALUE
+        @management_network_name = 'vagrant-libvirt' if @management_network_name == UNSET_VALUE
+        @management_network_address = '192.168.121.0/24' if @management_network_address == UNSET_VALUE
+        @management_network_mode = 'nat' if @management_network_mode == UNSET_VALUE
+        @management_network_mac = nil if @management_network_mac == UNSET_VALUE
+        @management_network_guest_ipv6 = 'yes' if @management_network_guest_ipv6 == UNSET_VALUE
+        @management_network_autostart = false if @management_network_autostart == UNSET_VALUE
+        @management_network_pci_bus = nil if @management_network_pci_bus == UNSET_VALUE
+        @management_network_pci_slot = nil if @management_network_pci_slot == UNSET_VALUE
+        @management_network_domain = nil if @management_network_domain == UNSET_VALUE
+        @management_network_mtu = nil if @management_network_mtu == UNSET_VALUE
+        @management_network_keep = false if @management_network_keep == UNSET_VALUE
+        @management_network_driver_iommu = false if @management_network_driver_iommu == UNSET_VALUE
+        @management_network_iface_name = nil if @management_network_iface_name == UNSET_VALUE
+        @management_network_model_type = @nic_model_type if @management_network_model_type == UNSET_VALUE
+
         @host_device_exclude_prefixes = ['docker', 'macvtap', 'virbr', 'vnet'] if @host_device_exclude_prefixes == UNSET_VALUE
       end
 
@@ -1206,27 +1230,7 @@ module VagrantPlugins
           errors << "#{e}"
         end
 
-        machine.config.vm.networks.each_with_index do |network, index|
-          type, opts = network
-
-          if opts[:mac]
-            if opts[:mac] =~ /\A([0-9a-fA-F]{12})\z/
-              opts[:mac] = opts[:mac].scan(/../).join(':')
-            end
-            unless opts[:mac] =~ /\A([0-9a-fA-F]{2}:){5}([0-9a-fA-F]{2})\z/
-              errors << "Configured NIC MAC '#{opts[:mac]}' is not in 'xx:xx:xx:xx:xx:xx' or 'xxxxxxxxxxxx' format"
-            end
-          end
-
-          # only interested in public networks where portgroup is nil, as then source will be a host device
-          if type == :public_network && opts[:portgroup] == nil
-            devices = host_devices(machine)
-            hostdev = opts.fetch(:dev, 'eth0')
-            if !devices.include?(hostdev)
-              errors << "network configuration #{index} for machine #{machine.name} is a public_network referencing host device '#{hostdev}' which does not exist, consider adding ':dev => ....' referencing one of #{devices.join(", ")}"
-            end
-          end
-        end
+        errors = validate_networks(machine, errors)
 
         if !machine.provider_config.volume_cache.nil? and machine.provider_config.volume_cache != UNSET_VALUE
           machine.ui.warn("Libvirt Provider: volume_cache is deprecated. Use disk_driver :cache => '#{machine.provider_config.volume_cache}' instead.")
@@ -1250,6 +1254,10 @@ module VagrantPlugins
           end
         end
 
+        if [@clock_absolute, @clock_adjustment, @clock_timezone].count {|clock| !clock.nil?} > 1
+          errors << "At most, only one of [clock_absolute, clock_adjustment, clock_timezone] may be set."
+        end
+
         errors = validate_sysinfo(machine, errors)
 
         { 'Libvirt Provider' => errors }
@@ -1320,8 +1328,8 @@ module VagrantPlugins
           end
         end
 
-        # Extract host values from uri if provided, otherwise nil
-        @host = uri.host
+        # Extract host values from uri if provided, otherwise set empty string
+        @host = uri.host || ""
         @port = uri.port
         # only override username if there is a value provided
         @username = nil if @username == UNSET_VALUE
@@ -1389,11 +1397,55 @@ module VagrantPlugins
         end
       end
 
-      def host_devices(machine)
-        machine.provider.driver.host_devices.select do |dev|
-          next if dev.empty?
-          dev != "lo" && !@host_device_exclude_prefixes.any? { |exclude| dev.start_with?(exclude) }
+      def validate_networks(machine, errors)
+        begin
+          networks = configured_networks(machine, @logger)
+        rescue Errors::VagrantLibvirtError => e
+          errors << "#{e}"
+
+          return
         end
+
+        return if networks.empty?
+
+        networks.each_with_index do |network, index|
+          if network[:mac]
+            if network[:mac] =~ /\A([0-9a-fA-F]{12})\z/
+              network[:mac] = network[:mac].scan(/../).join(':')
+            end
+            unless network[:mac] =~ /\A([0-9a-fA-F]{2}:){5}([0-9a-fA-F]{2})\z/
+              errors << "Configured NIC MAC '#{network[:mac]}' is not in 'xx:xx:xx:xx:xx:xx' or 'xxxxxxxxxxxx' format"
+            end
+          end
+
+          # only interested in public networks where portgroup is nil, as then source will be a host device
+          if network[:iface_type] == :public_network && network[:portgroup] == nil
+            exclude_prefixes = @host_device_exclude_prefixes
+            # for qemu sessions the management network injected will be a public_network trying to use a libvirt managed device
+            if index == 0 and machine.provider_config.mgmt_attach and machine.provider_config.qemu_use_session == true
+              exclude_prefixes.delete('virbr')
+            end
+
+            devices = machine.provider.driver.host_devices.select do |dev|
+              next if dev.empty?
+              dev != "lo" && !exclude_prefixes.any? { |exclude| dev.start_with?(exclude) }
+            end
+            hostdev = network.fetch(:dev, 'eth0')
+
+            if !devices.include?(hostdev)
+              errors << "network configuration #{index} for machine #{machine.name} is a public_network referencing host device '#{hostdev}' which does not exist, consider adding ':dev => ....' referencing one of #{devices.join(", ")}"
+            end
+          end
+
+          unless network[:iface_name].nil?
+            restricted_devnames = ['vnet', 'vif', 'macvtap', 'macvlan']
+            if restricted_devnames.any? { |restricted| network[:iface_name].start_with?(restricted) }
+              errors << "network configuration for machine #{machine.name} with setting :libvirt__iface_name => '#{network[:iface_name]}' starts with a restricted prefix according to libvirt docs https://libvirt.org/formatdomain.html#overriding-the-target-element, please use a device name that does not start with one of #{restricted_devnames.join(", ")}"
+            end
+          end
+        end
+
+        errors
       end
 
       def validate_sysinfo(machine, errors)
