@@ -3,6 +3,7 @@
 require 'ipaddr'
 require 'nokogiri'
 require 'vagrant/util/network_ip'
+require 'vagrant/util/scoped_hash_override'
 
 class IPAddr
   def get_mask
@@ -17,23 +18,58 @@ module VagrantPlugins
     module Util
       module NetworkUtil
         include Vagrant::Util::NetworkIP
+        include Vagrant::Util::ScopedHashOverride
 
-        def configured_networks(env, logger)
-          qemu_use_session = env[:machine].provider_config.qemu_use_session
-          qemu_use_agent = env[:machine].provider_config.qemu_use_agent
-          management_network_device = env[:machine].provider_config.management_network_device
-          management_network_name = env[:machine].provider_config.management_network_name
-          management_network_address = env[:machine].provider_config.management_network_address
-          management_network_mode = env[:machine].provider_config.management_network_mode
-          management_network_mac = env[:machine].provider_config.management_network_mac
-          management_network_guest_ipv6 = env[:machine].provider_config.management_network_guest_ipv6
-          management_network_autostart = env[:machine].provider_config.management_network_autostart
-          management_network_pci_bus = env[:machine].provider_config.management_network_pci_bus
-          management_network_pci_slot = env[:machine].provider_config.management_network_pci_slot
-          management_network_domain = env[:machine].provider_config.management_network_domain
-          management_network_mtu = env[:machine].provider_config.management_network_mtu
-          management_network_keep = env[:machine].provider_config.management_network_keep
-          management_network_driver_iommu = env[:machine].provider_config.management_network_driver_iommu
+        def network_interfaces(machine, logger)
+          # Setup list of interfaces before creating them.
+          adapters = []
+
+          # Vagrant gives you adapter 0 by default
+          # Assign interfaces to slots.
+          configured_networks(machine, logger).each do |options|
+            # don't need to create interface for this type
+            next if options[:iface_type] == :forwarded_port
+
+            # TODO: fill first ifaces with adapter option specified.
+            if options[:adapter]
+              if adapters[options[:adapter]]
+                raise Errors::InterfaceSlotNotAvailable
+              end
+
+              free_slot = options[:adapter].to_i
+              @logger.debug "Using specified adapter slot #{free_slot}"
+            else
+              free_slot = find_empty(adapters, 0, machine.provider_config.nic_adapter_count)
+              @logger.debug "Adapter not specified so found slot #{free_slot}"
+              raise Errors::InterfaceSlotExhausted if free_slot.nil?
+            end
+
+            # We have slot for interface, fill it with interface configuration.
+            adapters[free_slot] = options
+            adapters[free_slot][:network_name] = interface_network(machine.provider.driver, adapters[free_slot])
+          end
+
+          adapters
+        end
+
+        def configured_networks(machine, logger)
+          qemu_use_session = machine.provider_config.qemu_use_session
+          qemu_use_agent = machine.provider_config.qemu_use_agent
+          management_network_device = machine.provider_config.management_network_device
+          management_network_name = machine.provider_config.management_network_name
+          management_network_address = machine.provider_config.management_network_address
+          management_network_mode = machine.provider_config.management_network_mode
+          management_network_mac = machine.provider_config.management_network_mac
+          management_network_guest_ipv6 = machine.provider_config.management_network_guest_ipv6
+          management_network_autostart = machine.provider_config.management_network_autostart
+          management_network_pci_bus = machine.provider_config.management_network_pci_bus
+          management_network_pci_slot = machine.provider_config.management_network_pci_slot
+          management_network_domain = machine.provider_config.management_network_domain
+          management_network_mtu = machine.provider_config.management_network_mtu
+          management_network_keep = machine.provider_config.management_network_keep
+          management_network_driver_iommu = machine.provider_config.management_network_driver_iommu
+          management_network_iface_name = machine.provider_config.management_network_iface_name
+          management_network_model_type = machine.provider_config.management_network_model_type
           logger.info "Using #{management_network_name} at #{management_network_address} as the management network #{management_network_mode} is the mode"
 
           begin
@@ -54,6 +90,7 @@ module VagrantPlugins
           if qemu_use_session
             management_network_options = {
               iface_type: :public_network,
+              model_type: management_network_model_type,
               dev: management_network_device,
               mode: 'bridge',
               type: 'bridge',
@@ -63,6 +100,7 @@ module VagrantPlugins
           else
             management_network_options = {
               iface_type: :private_network,
+              model_type: management_network_model_type,
               network_name: management_network_name,
               ip: Regexp.last_match(1),
               netmask: Regexp.last_match(2),
@@ -76,6 +114,7 @@ module VagrantPlugins
           end
 
           management_network_options[:driver_iommu] = management_network_driver_iommu
+          management_network_options[:iface_name] = management_network_iface_name
 
           unless management_network_mac.nil?
             management_network_options[:mac] = management_network_mac
@@ -101,23 +140,23 @@ module VagrantPlugins
           # if there is a box and management network is disabled
           # need qemu agent enabled and at least one network that can be accessed
           if (
-            env[:machine].config.vm.box &&
-            !env[:machine].provider_config.mgmt_attach &&
-            !env[:machine].provider_config.qemu_use_agent &&
-            !env[:machine].config.vm.networks.any? { |type, _| ["private_network", "public_network"].include?(type.to_s) }
+            machine.config.vm.box &&
+            !machine.provider_config.mgmt_attach &&
+            !machine.provider_config.qemu_use_agent &&
+            !machine.config.vm.networks.any? { |type, _| ["private_network", "public_network"].include?(type.to_s) }
           )
             raise Errors::ManagementNetworkRequired
           end
 
           # add management network to list of networks to check
           # unless mgmt_attach set to false
-          networks = if env[:machine].provider_config.mgmt_attach
+          networks = if machine.provider_config.mgmt_attach
                        [management_network_options]
                      else
                        []
                      end
 
-          env[:machine].config.vm.networks.each do |type, original_options|
+          machine.config.vm.networks.each do |type, original_options|
             logger.debug "In config found network type #{type} options #{original_options}"
             # Options can be specified in Vagrantfile in short format (:ip => ...),
             # or provider format # (:libvirt__network_name => ...).
@@ -193,6 +232,41 @@ module VagrantPlugins
 
           libvirt_networks
         end
+
+        def find_empty(array, start, stop)
+          (start..stop).each do |i|
+            return i unless array[i]
+          end
+          nil
+        end
+
+        # Return network name according to interface options.
+        def interface_network(driver, options)
+          # no need to get interface network for tcp tunnel config
+          return 'tunnel_interface' if options.fetch(:tunnel_type, nil)
+
+          if options[:network_name]
+            @logger.debug 'Found network by name'
+            return options[:network_name]
+          end
+
+          # Get list of all (active and inactive) Libvirt networks.
+          available_networks = libvirt_networks(driver)
+
+          return 'public' if options[:iface_type] == :public_network
+
+          if options[:ip]
+            address = network_address(options[:ip], options[:netmask])
+            available_networks.each do |network|
+              if address == network[:network_address]
+                @logger.debug 'Found network by ip'
+                return network[:name]
+              end
+            end
+          end
+
+          raise Errors::NetworkNotAvailableError, network_name: options[:ip]
+        end
       end
     end
   end
