@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-require 'spec_helper'
-require 'support/sharedcontext'
-require 'support/libvirt_context'
+require_relative '../../spec_helper'
 
 require 'fog/libvirt/models/compute/volume'
 
@@ -64,6 +62,24 @@ describe VagrantPlugins::ProviderLibvirt::Action::CreateDomain do
         expect(subject.call(env)).to be_nil
       end
 
+      context 'graphics autoport disabled' do
+        let(:vagrantfile_providerconfig) do
+          <<-EOF
+          libvirt.graphics_port = 5900
+          libvirt.graphics_websocket = 5700
+          EOF
+        end
+
+        it 'should emit the graphics port and websocket' do
+          expect(servers).to receive(:create).and_return(machine)
+          expect(volumes).to_not receive(:create) # additional disks only
+          expect(ui).to receive(:info).with(' -- Graphics Port:     5900')
+          expect(ui).to receive(:info).with(' -- Graphics Websocket: 5700')
+
+          expect(subject.call(env)).to be_nil
+        end
+      end
+
       context 'additional disks' do
         let(:disks) do
           [
@@ -171,6 +187,38 @@ describe VagrantPlugins::ProviderLibvirt::Action::CreateDomain do
         end
       end
 
+      context 'launchSecurity' do
+        let(:vagrantfile_providerconfig) do
+          <<-EOF
+          libvirt.launchsecurity :type => 'sev', :cbitpos => 47, :reducedPhysBits => 1, :policy => "0x0003"
+          EOF
+        end
+
+        it 'should emit the settings to the ui' do
+          expect(ui).to receive(:info).with(/ -- Launch security:   type=sev, cbitpos=47, reducedPhysBits=1, policy=0x0003/)
+          expect(servers).to receive(:create).and_return(machine)
+
+          expect(subject.call(env)).to be_nil
+        end
+      end
+
+      context 'memtunes' do
+        let(:vagrantfile_providerconfig) do
+          <<-EOF
+          libvirt.memtune :type => 'hard_limit', :value => 250000
+          libvirt.memtune :type => 'soft_limit', :value => 200000
+          EOF
+        end
+
+        it 'should emit the settings to the ui' do
+          expect(ui).to receive(:info).with(/ -- Memory Tuning:     hard_limit: unit='KiB', value: 250000/)
+          expect(ui).to receive(:info).with(/ -- Memory Tuning:     soft_limit: unit='KiB', value: 200000/)
+          expect(servers).to receive(:create).and_return(machine)
+
+          expect(subject.call(env)).to be_nil
+        end
+      end
+
       context 'sysinfo' do
         let(:domain_xml_file) { 'sysinfo.xml' }
         let(:vagrantfile_providerconfig) do
