@@ -86,7 +86,7 @@ describe VagrantPlugins::ProviderLibvirt::Config do
         ],
         [ # connect explicit to unix socket
           {:uri => "qemu+unix:///system"},
-          {:uri => "qemu+unix:///system", :connect_via_ssh => false, :host => nil, :username => nil},
+          {:uri => "qemu+unix:///system", :connect_via_ssh => false, :host => "", :username => nil},
         ],
         [ # via libssh2 should enable ssh as well
           {:uri => "qemu+libssh2://user@remote/system?known_hosts=/home/user/.ssh/known_hosts"},
@@ -139,7 +139,7 @@ describe VagrantPlugins::ProviderLibvirt::Config do
         ],
         [ # with session and using ssh infer connect by ssh and ignore host as not provided
           {},
-          {:uri => "qemu+ssh:///session", :qemu_use_session => true, :connect_via_ssh => true, :host => nil},
+          {:uri => "qemu+ssh:///session", :qemu_use_session => true, :connect_via_ssh => true, :host => ""},
           {
             :env => {'LIBVIRT_DEFAULT_URI' => "qemu+ssh:///session"},
           }
@@ -768,8 +768,13 @@ describe VagrantPlugins::ProviderLibvirt::Config do
 
     context 'with mac defined' do
       let (:vm) { double('vm') }
+      let(:box) { instance_double(::Vagrant::Box) }
+
       before do
         machine.config.instance_variable_get("@keys")[:vm] = vm
+        allow(vm).to receive(:box).and_return(box)
+
+        allow(vm).to receive(:synced_folders).and_return({})
       end
 
       it 'is valid with valid mac' do
@@ -781,7 +786,7 @@ describe VagrantPlugins::ProviderLibvirt::Config do
         network = [:public, { mac: 'aabbccddeeff' }]
         expect(vm).to receive(:networks).and_return([network])
         assert_valid
-        expect(network[1][:mac]).to eql('aa:bb:cc:dd:ee:ff')
+        expect(network[1][:mac]).to eql('aabbccddeeff')
       end
 
       it 'should be invalid if MAC not formatted correctly' do
@@ -798,8 +803,9 @@ describe VagrantPlugins::ProviderLibvirt::Config do
         'virbr0',
       ] }
       let(:driver) { instance_double(::VagrantPlugins::ProviderLibvirt::Driver) }
+      let(:device_name) { 'eth0' }
       before do
-        machine.config.vm.network :public_network, dev: 'eth0', ip: "192.168.2.157"
+        machine.config.vm.network :public_network, dev: device_name, ip: "192.168.2.157"
         allow(machine.provider).to receive(:driver).and_return(driver)
         expect(driver).to receive(:host_devices).and_return(host_devices).at_least(:once).times
       end
@@ -809,9 +815,7 @@ describe VagrantPlugins::ProviderLibvirt::Config do
       end
 
       context 'when default device not on host' do
-        before do
-          machine.config.vm.network :public_network, dev: 'eno1', ip: "192.168.2.157"
-        end
+        let(:device_name) { 'eno1' }
 
         it 'should be invalid' do
           assert_invalid
@@ -819,9 +823,7 @@ describe VagrantPlugins::ProviderLibvirt::Config do
       end
 
       context 'when using excluded host device' do
-        before do
-          machine.config.vm.network :public_network, dev: 'virbr0', ip: "192.168.2.157"
-        end
+        let(:device_name) { 'virbr0' }
 
         it 'should be invalid' do
           assert_invalid
@@ -837,6 +839,27 @@ describe VagrantPlugins::ProviderLibvirt::Config do
           end
         end
       end
+
+      context 'when setting iface_name' do
+        let(:iface_name) { 'myvnet1' }
+
+        before do
+          machine.config.vm.network :public_network, libvirt__iface_name: iface_name, ip: "192.168.2.157"
+        end
+
+        it 'should valididate' do
+          assert_valid
+        end
+
+        context 'when set to reserved value' do
+          let(:iface_name) { 'vnet1' }
+
+          it 'should be invalid' do
+            errors = assert_invalid
+            expect(errors).to include(match(/network configuration for machine test with setting :libvirt__iface_name => '#{iface_name}' starts/))
+          end
+        end
+      end
     end
 
     context 'with nvram defined' do
@@ -996,10 +1019,16 @@ describe VagrantPlugins::ProviderLibvirt::Config do
         EOF
       end
       let(:driver) { instance_double(::VagrantPlugins::ProviderLibvirt::Driver) }
+      let(:host_devices) { [
+        'lo',
+        'eth0',
+        'virbr0',
+      ] }
 
       before do
         allow(machine.provider).to receive(:driver).and_return(driver)
         allow(driver).to receive_message_chain('connection.client.libversion').and_return(6_002_000)
+        allow(driver).to receive(:host_devices).and_return(host_devices)
       end
 
       context 'when type is 9p' do
